PrintColor enum

Specifies all possible Colors

Inheritance
Available extensions

Values

normal → const PrintColor

Default message code

const PrintColor("\x1B[0m")
blue → const PrintColor

Blue message code

const PrintColor("\x1B[34m")
red → const PrintColor

Red message code

const PrintColor("\x1B[31m")
green → const PrintColor

Green message code

const PrintColor("\x1B[32m")

Properties

code → String
Add code at the beginning of your print text and the message will appear in the respective color.
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PrintColor>
A constant List of the values in this enum, in order of their declaration.